#!/bin/bash

##################################################################
#Set application name
appName=GeoFIS

# Define minimum java version
minJavaVersionMajor=1
minJavaVersionMinor=8
minJavaVersionPatch=0

# env var $JAVA_OPTS is set with default values if not set
##################################################################

GEOFIS_PATH="`dirname \"$0\"`"
GEOFIS_PATH="`( cd \"$GEOFIS_PATH\" && pwd )`"
cd $GEOFIS_PATH

# Setting Java environment variables
if [ -z "$JAVA_HOME" ]; then # if JAVA_HOME is not set
	export JAVA_HOME="`readlink -f /usr/bin/javac | sed "s:/bin/javac::"`" 	
fi
export JAVA="$JAVA_HOME/bin/java" 
export JAVAC="$JAVA_HOME/bin/javac"
export JAVAH="$JAVA_HOME/bin/javah"
export JAR="$JAVA_HOME/bin/jar"
# JAVA_LIBS, JAVA_LD_LIBRARY_PATH and JAVA_CPPFLAGS needed to compile rJava package
if [ -d "$JAVA_HOME/jre" ]; then # if JRE directory exists 
	if [ "`uname -m`" = "x86_64" ]; then
		ARCH=amd64 
	else
		ARCH=i386 
	fi
	export JAVA_LIBS="-L$JAVA_HOME/jre/lib/$ARCH/server -ljvm"
	export JAVA_LD_LIBRARY_PATH="$JAVA_HOME/jre/lib/$ARCH/server"
else # openjdk 11 has no JRE folder
	export JAVA_LIBS="-L$JAVA_HOME/lib/server -ljvm"
	export JAVA_LD_LIBRARY_PATH="$JAVA_HOME/lib/server"
fi	
export JAVA_CPPFLAGS="-I$JAVA_HOME/include -I$JAVA_HOME/include/linux"

# Check JAVA_OPTS and set with defaults if not set
if [ -z "$JAVA_OPTS" ]; then # if JAVA_OPTS not set
  	# Add what you like...
  	JAVA_OPTS="-Xss1m -Xms512m -Xmx1024m "
fi

# Java Discovery
if ( which $JAVA 2>&1 > /dev/null ); then
  	echo -n ''
else
  	echo 'Cannot find Java. Please install Java or set your JAVA_HOME environment variable.'
  	exit 1
fi

# Check Java Version
javaVersion=`$JAVA -version 2>&1 | awk 'NR==1{ gsub(/"/,""); print $3 }'`
javaVersionMajor=`echo $javaVersion | awk -F . '{print $1}'`
javaVersionMinor=`echo $javaVersion | awk -F . '{print $2}'`
javaVersionPatch=`echo $javaVersion | awk -F . '{print $3}' | awk -F _ '{print $2}'`

if [ $javaVersionMajor -gt $minJavaVersionMajor ]; then
	echo -n ''
else
  	if 	[ $javaVersionMajor -eq $minJavaVersionMajor ] &&
     	[ $javaVersionMinor -gt $minJavaVersionMinor ]; then
		echo -n ''
  	else
    	if 	[ $javaVersionMajor -eq $minJavaVersionMajor ] &&
       		[ $javaVersionMinor -eq $minJavaVersionMinor ] &&
       		[ $javaVersionPatch -ge $minJavaVersionPatch ]; then
      		echo -n ''
    	else
 	  		echo "Found Java version:    $javaVersionMajor.$javaVersionMinor.$javaVersionPatch"
	  		echo "Required Java version: $minJavaVersionMajor.$minJavaVersionMinor.$minJavaVersionPatch"
      		echo 'Please update your Java to the required Java version !'
      		exit 1;
    	fi
    fi
fi

# Java JVM options (enable modules)
if [ $javaVersionMajor -ge 11 ]; then
	JAVA_JVM="--add-opens java.base/java.io=ALL-UNNAMED"
	JAVA_JVM="$JAVA_JVM --add-opens java.base/java.lang=ALL-UNNAMED"
	JAVA_JVM="$JAVA_JVM --add-opens java.base/java.nio.file.spi=ALL-UNNAMED"
	JAVA_JVM="$JAVA_JVM --add-opens java.base/java.util=ALL-UNNAMED"
	JAVA_JVM="$JAVA_JVM --add-opens java.base/sun.nio.fs=ALL-UNNAMED"
	JAVA_JVM="$JAVA_JVM --add-opens java.desktop/com.sun.imageio.plugins.jpeg=ALL-UNNAMED"
	JAVA_JVM="$JAVA_JVM --add-opens java.desktop/java.awt=ALL-UNNAMED"
	JAVA_JVM="$JAVA_JVM --add-opens java.desktop/javax.swing.plaf.metal=ALL-UNNAMED"
fi

# Setting R environment variables
export R_JAVA_LD_LIBRARY_PATH=$JAVA_LD_LIBRARY_PATH # needed for rJava installation
if [ -z "$R_HOME" ]; then # if R_HOME not set
	R="`which R`"
	if [ $? -eq 0 ]; then
		export R_HOME="`R -e "cat(Sys.getenv('R_HOME'))" --slave`" # read R_HOME from R
	fi
fi
export MAKEFLAGS=-j`nproc` # for parallel compilation of R packages 

# Launch GeoFIS
export LC_NUMERIC=C
export LD_LIBRARY_PATH=$GEOFIS_PATH/bin
exec -a $appName $JAVA $JAVA_JVM $JAVA_OPTS -splash:geofis-splash.png -classpath *:lib/* org.geofis.main.Main
