
#' takes a subset of the input data and returns it as output
#'
#' @param data spatial data.frame, the input data
#' @param attribute character, the attribute name (optional, can be NULL)
#' @param sample_percent integer, the size of the subset (in percent of data size, range [0, 100])
#'
#' @return the subset of the input data
#'
make_sample <- function(data, attribute, sample_percent) {
  if (is.null(sample_percent)) {
    stop("sample_percent must not be null")
  }
  n <- dim(data)[1]
  s <- sample.int(n, size = sample_percent / 100 * n, replace = FALSE) # line index
  if (is.null(attribute)) {
    data[s, ] # sample all
  }
  else {
    data[s, attribute] # sample attribute
  }
}

#' Compute the mean of the selected attribute
#'
#' @param data spatial data.frame, the input data
#' @param attribute character, the attribute name used to compute the mean (could be NULL)
#'
#' @return the mean of selected attribute, or NULL if no selected attribute or attribute is not numeric.
#'
compute_mean_attribute <- function(data, attribute) {
  if (is.null(attribute)) {
    NULL
  } else {
    if (is.numeric(data[[attribute]])) {
      mean(data[[attribute]])
    } else {
      NULL
    }
  }
}
